
//-----------------------------------------------------------------------------

float4x4 WorldViewProj : WorldViewProjection;

//-----------------------------------------------------------------------------

struct VS_INPUT {
    float4 Position : POSITION;
    float3 Normal   : NORMAL;
    float3 Color    : COLOR0;
    float2 TexCoord : TEXCOORD0;
};

struct VS_OUTPUT {
    float4 oPosition  : POSITION;
    float3 oColor     : COLOR;
};

//-----------------------------------------------------------------------------

VS_OUTPUT SimpleVS(const VS_INPUT IN)
{
    VS_OUTPUT OUT;
    
	// Transform vertex position to clip space
	OUT.oPosition = mul(IN.Position, WorldViewProj);	

    OUT.oColor = IN.Color;
	
    return OUT;
}

float4 SimplePS(VS_OUTPUT IN) : COLOR
{
    return float4(IN.oColor, 1);
}

technique Simple
{
    pass P0
    {
        VertexShader = compile vs_1_1 SimpleVS();
        PixelShader = compile ps_1_1 SimplePS();

        // other settings (play it safe):
        AlphaBlendEnable = False;
        Lighting = False;
        
		ColorOp[0] = SelectArg1;
		ColorArg1[0] = Diffuse;
		ColorOp[1] = Disable;

		AlphaOp[0] = SelectArg1;
		AlphaArg1[0] = Diffuse;
		AlphaOp[1] = Disable;
	}
}

technique SimpleNoZorColorWrite
{
    pass P0
    {
        VertexShader = compile vs_1_1 SimpleVS();
        PixelShader = compile ps_1_1 SimplePS();
        
        // turn off color masks and zwrite
        ZWriteEnable = 0;
        ColorWriteEnable = 0;

        // other settings (play it safe):
        AlphaBlendEnable = False;
        Lighting = False;
        
		ColorOp[0] = SelectArg1;
		ColorArg1[0] = Diffuse;
		ColorOp[1] = Disable;

		AlphaOp[0] = SelectArg1;
		AlphaArg1[0] = Diffuse;
		AlphaOp[1] = Disable;
	}
}

//-----------------------------------------------------------------------------

VS_OUTPUT ComplexVS(const VS_INPUT IN)
{
    // Just call the simple vertex shader, for this demo;
    // normally, you'd put a high-quality shader in here
    // for your complex object.
    
    return SimpleVS(IN);
}

float4 ComplexPS(VS_OUTPUT IN) : COLOR
{
    // Just call the simple pixel shader, for this demo;
    // normally, you'd put a high-quality shader in here
    // for your complex object.
    
    return SimplePS(IN);
}

technique Complex
{
    pass P0
    {
        VertexShader = compile vs_1_1 ComplexVS();
        PixelShader = compile ps_1_1 ComplexPS();
        
        // other settings (play it safe):
        AlphaBlendEnable = False;
        Lighting = False;
        
		ColorOp[0] = SelectArg1;
		ColorArg1[0] = Diffuse;
		ColorOp[1] = Disable;

		AlphaOp[0] = SelectArg1;
		AlphaArg1[0] = Diffuse;
		AlphaOp[1] = Disable;
	}
}

//-----------------------------------------------------------------------------
